@@ -30,4 +30,16 @@ pop <- NULL
 
 #' centers
 #' @name centers
-centers <- NULL
\ No newline at end of file
+centers <- NULL
+
+
+#' Labels to translate leafepp maps.
+#'
+#' A dataset containing the labels to translate leafepp maps.
+#'
+#' @format A data frame with 16 rows and 2 variables:
+#' \describe{
+#'   \item{en}{English labels}
+#'   \item{es}{Spanish labels}
+#' }
+"labels_es"
\ No newline at end of file
